[Scummvm-cvs-logs] SF.net SVN: scummvm:[47725] scummvm/trunk/engines/sci/engine

fingolfin at users.sourceforge.net fingolfin at users.sourceforge.net
Sat Jan 30 20:06:24 CET 2010


Revision: 47725
          http://scummvm.svn.sourceforge.net/scummvm/?rev=47725&view=rev
Author:   fingolfin
Date:     2010-01-30 19:06:24 +0000 (Sat, 30 Jan 2010)

Log Message:
-----------
SCI: Correct comments which talked about 'loading from GMM' when they really meant 'loading from launcher'

Modified Paths:
--------------
    scummvm/trunk/engines/sci/engine/kfile.cpp
    scummvm/trunk/engines/sci/engine/vm.cpp

Modified: scummvm/trunk/engines/sci/engine/kfile.cpp
===================================================================
--- scummvm/trunk/engines/sci/engine/kfile.cpp	2010-01-30 19:04:21 UTC (rev 47724)
+++ scummvm/trunk/engines/sci/engine/kfile.cpp	2010-01-30 19:06:24 UTC (rev 47725)
@@ -608,7 +608,7 @@
 
 		savedir_nr = saves[savedir_nr].id;
 	} else {
-		// Loading from GMM, no change necessary
+		// Loading from launcher, no change necessary
 	}
 
 	if (savedir_nr > -1) {

Modified: scummvm/trunk/engines/sci/engine/vm.cpp
===================================================================
--- scummvm/trunk/engines/sci/engine/vm.cpp	2010-01-30 19:04:21 UTC (rev 47724)
+++ scummvm/trunk/engines/sci/engine/vm.cpp	2010-01-30 19:06:24 UTC (rev 47725)
@@ -543,10 +543,10 @@
 	reg_t r_temp; // Temporary register
 	StackPtr s_temp; // Temporary stack pointer
 	int16 opparams[4]; // opcode parameters
-	bool loadFromGMM = ConfMan.hasKey("save_slot") ? true : false;
-	if (loadFromGMM) {
+	bool loadFromLauncher = ConfMan.hasKey("save_slot") ? true : false;
+	if (loadFromLauncher) {
 		if (ConfMan.getInt("save_slot") < 0)
-			loadFromGMM = false;	// already loaded
+			loadFromLauncher = false;	// already loaded
 	}
 
 	scriptState.restAdjust = s->restAdjust;
@@ -1042,18 +1042,18 @@
 						//warning("callk %s", kfun.orig_name.c_str());
 
 						// TODO: SCI2/SCI2.1+ equivalent, once saving/loading works in SCI2/SCI2.1+
-						if (loadFromGMM && opparams[0] == 0x8) {
-							// A game is being loaded from GMM, and kDisplay is called, all initialization has taken
+						if (loadFromLauncher && opparams[0] == 0x8) {
+							// A game is being loaded from the launcher, and kDisplay is called, all initialization has taken
 							// place (i.e. menus have been constructed etc). Therefore, inject a kRestoreGame call
-							// here, instead of the requested function
+							// here, instead of the requested function.
 							int saveSlot = ConfMan.getInt("save_slot");
 							ConfMan.setInt("save_slot", -1);	// invalidate slot
-							loadFromGMM = false;
+							loadFromLauncher = false;
 
 							if (saveSlot < 0)
 								error("Requested to load invalid save slot");	// should never happen, really
 
-							reg_t restoreArgv[2] = { NULL_REG, make_reg(0, saveSlot) };	// special GMM call (argv[0] is NULL)
+							reg_t restoreArgv[2] = { NULL_REG, make_reg(0, saveSlot) };	// special call (argv[0] is NULL)
 							kRestoreGame(s, 2, restoreArgv);
 						} else {
 							// Call kernel function


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list